@@ -23,6 +23,8 @@ from client_sdk_python.testing import Testing
 from client_sdk_python.txpool import TxPool
 from client_sdk_python.version import Version
 from client_sdk_python.debug import Debug
+from client_sdk_python.ppos import Ppos
+from client_sdk_python.pip import Pip
 
 from client_sdk_python.providers.eth_tester import (
     EthereumTesterProvider,
@@ -60,6 +62,7 @@ from client_sdk_python.utils.encoding import (
     to_int,
     to_hex,
     to_text,
+    analyze,
 )
 from client_sdk_python.utils.normalizers import (
     abi_ens_resolver,
@@ -79,6 +82,8 @@ def get_default_modules():
         "parity": Parity,
         "testing": Testing,
         "debug": Debug,
+        "pip": Pip,
+        "ppos": Ppos
     }
 
 
@@ -106,12 +111,20 @@ class Web3:
     toWei = staticmethod(to_wei)
     fromWei = staticmethod(from_wei)
 
+    analyzeReceipt = staticmethod(analyze)
+
     # Address Utility
     isAddress = staticmethod(is_address)
     isChecksumAddress = staticmethod(is_checksum_address)
     toChecksumAddress = staticmethod(to_checksum_address)
 
-    def __init__(self, providers=empty, middlewares=None, modules=None, ens=empty):
+    # platon contract address
+    restrictingAddress = "0x1000000000000000000000000000000000000001"
+    stakingAddress = "0x1000000000000000000000000000000000000002"
+    penaltyAddress = "0x1000000000000000000000000000000000000004"
+    pipAddress = "0x1000000000000000000000000000000000000005"
+
+    def __init__(self, providers=empty, middlewares=None, modules=None, ens=empty, chain_id=101):
         self.manager = RequestManager(self, providers, middlewares)
 
         if modules is None:
@@ -122,6 +135,15 @@ class Web3:
 
         self.ens = ens
 
+        self.chain_id = chain_id
+
+    def setChainId(self, chain_id):
+        self.chain_id = chain_id
+
+    @property
+    def chainId(self):
+        return self.chain_id
+
     @property
     def middleware_stack(self):
         return self.manager.middleware_stack
